==> ogre-next-2.3.0-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/class_ogre_1_1_vulkan_vao_manager.js <==
var class_ogre_1_1_vulkan_vao_manager =
[
    [ "Block", "struct_ogre_1_1_vulkan_vao_manager_1_1_block.html", "struct_ogre_1_1_vulkan_vao_manager_1_1_block" ],
    [ "StrideChanger", "struct_ogre_1_1_vulkan_vao_manager_1_1_stride_changer.html", "struct_ogre_1_1_vulkan_vao_manager_1_1_stride_changer" ],
    [ "BlockVec", "class_ogre_1_1_vulkan_vao_manager.html#a0283b00d7e9d9e2213fb148c0373b3b7", null ],
    [ "MemoryStatsEntryVec", "class_ogre_1_1_vulkan_vao_manager.html#a8a984ae987b00e95b35198131a4e9a6b", null ],
    [ "StrideChangerVec", "class_ogre_1_1_vulkan_vao_manager.html#af11ca95197171f47071cbdfc64244a4f", null ],
    [ "VboFlag", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6", [
      [ "CPU_INACCESSIBLE", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6adc08b2860b6cf9300228b283c5e651bd", null ],
      [ "CPU_WRITE_PERSISTENT", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6aec008c6e31eaa44bfa5e74b7decb389f", null ],
      [ "CPU_WRITE_PERSISTENT_COHERENT", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6aebeeeb1acff523546cb20cdbded0c5a1", null ],
      [ "CPU_READ_WRITE", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6a4c69f747f4f94bb8b821acc0eacf676a", null ],
      [ "TEXTURES_OPTIMAL", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6ad1e8da73c7fc5e3ce7de33801b73f247", null ],
      [ "MAX_VBO_FLAG", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6a1faa3e29dbe49f9f22a09f8d01e18bd0", null ]
    ] ],
    [ "VulkanVaoManager", "class_ogre_1_1_vulkan_vao_manager.html#af585c27cb1ae67c757a1b32df69fb9fe", null ],
    [ "~VulkanVaoManager", "class_ogre_1_1_vulkan_vao_manager.html#a7a7ced25ae7b1eae789a2f415c39aade", null ],
    [ "_beginFrame", "class_ogre_1_1_vulkan_vao_manager.html#ad255ed9aad893f120f6a29e172052ccd", null ],
    [ "_getDynamicBufferCurrentFrameNoWait", "class_ogre_1_1_vulkan_vao_manager.html#a4c2c223f495c035085ffa2b7323bce82", null ],
    [ "_notifyDeviceStalled", "class_ogre_1_1_vulkan_vao_manager.html#a802df1807930b35819e86bb79a733026", null ],
    [ "_notifyNewCommandBuffer", "class_ogre_1_1_vulkan_vao_manager.html#ac786e9cda28b0dc567b9af12e6ddb8a1", null ],
    [ "_notifyStagingBufferEnteredZeroRef", "class_ogre_1_1_vulkan_vao_manager.html#a374058250675bac30bfb5b03c26b5eb7", null ],
    [ "_notifyStagingBufferLeftZeroRef", "class_ogre_1_1_vulkan_vao_manager.html#ace2545e4ce03ff536e3d505e4669cc91", null ],
    [ "_schedulePoolAdvanceFrame", "class_ogre_1_1_vulkan_vao_manager.html#a6c95b6cd736eb88e5dc4f4a0e9a52cae", null ],
    [ "_update", "class_ogre_1_1_vulkan_vao_manager.html#afafd75ba72857e13a55e540a2d0ed414", null ],
    [ "addDelayedFunc", "class_ogre_1_1_vulkan_vao_manager.html#a9c1168472c2c1b564613933fb1c1b6b5", null ],
    [ "allocateRawBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a2870e34d1f38436b26304d046d824aa9", null ],
    [ "allocateTexture", "class_ogre_1_1_vulkan_vao_manager.html#afbc41371222b8bad4d0df08b1edeba2a", null ],
    [ "bindDrawIdVertexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a5ee3a6b573c776419fab5b4da3a0b2fc", null ],
    [ "calculateVertexSize", "class_ogre_1_1_vulkan_vao_manager.html#a222d4e40df5eb53ab0b050e37aca7b89", null ],
    [ "cleanupEmptyPools", "class_ogre_1_1_vulkan_vao_manager.html#aaffa3ad1e24be33801e33b21e028f88d", null ],
    [ "createAsyncTicket", "class_ogre_1_1_vulkan_vao_manager.html#a07071887711dbb653fe790224beb7d3b", null ],
    [ "createConstBuffer", "class_ogre_1_1_vulkan_vao_manager.html#ad918478b8b2fe87bd0cf5a0d800f9ca8", null ],
    [ "createIndexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#aaee81b43cbfe73850b5f48e0b3b04b2d", null ],
    [ "createIndirectBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a62af7df3a3d8cbe692a621741aa12e5c", null ],
    [ "createReadOnlyBuffer", "class_ogre_1_1_vulkan_vao_manager.html#af7c18af1342b5ae1a15d55838b667935", null ],
    [ "createStagingBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a27f67d725f1e4600d946307a831949c8", null ],
    [ "createStagingTexture", "class_ogre_1_1_vulkan_vao_manager.html#a9e35cf192da6357d94b33a75ad94cba6", null ],
    [ "createTexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a9746fd2364a65422ca7beafef42ad82b", null ],
    [ "createUavBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a0937a414f9da637fb8878e10db724bba", null ],
    [ "createVertexArrayObject", "class_ogre_1_1_vulkan_vao_manager.html#a21be4e3d6b7ad0490c59eb9db1cdcdf7", null ],
    [ "createVertexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#aefabb42c2a1a8f2d71af28ffaa91ba91", null ],
    [ "deallocateRawBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a3c44f33fd9c8a89eb68c970fab17b7b7", null ],
    [ "deallocateTexture", "class_ogre_1_1_vulkan_vao_manager.html#a55fb0b0643f47ed4de330528d614ce07", null ],
    [ "deleteStagingBuffers", "class_ogre_1_1_vulkan_vao_manager.html#a204c8055903cea82fe38e6a9fbc62f6d", null ],
    [ "destroyConstBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a51f5147151805c3d294ae200683d76bb", null ],
    [ "destroyIndexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a04c53b84b4c6ba27fdcbf57a08d4b044", null ],
    [ "destroyIndirectBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a4e7e88128e2496523ab0ca8e35634879", null ],
    [ "destroyReadOnlyBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a703bff2ff022184c4f40da6ecb9a19ee", null ],
    [ "destroyStagingTexture", "class_ogre_1_1_vulkan_vao_manager.html#a39ec5e085c6183db97d875c57ca92f0b", null ],
    [ "destroyTexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a6241229a8f3c895dcd49e7d0e8dfe545", null ],
    [ "destroyUavBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a0f235ad527a20a7c20b9daae8dc18ff7", null ],
    [ "destroyVertexArrayObject", "class_ogre_1_1_vulkan_vao_manager.html#a4d56b87f51c489bdc2df07d1ce040512", null ],
    [ "destroyVertexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a1dce3c8cb8c7d08ff77e6c4776fed1f4", null ],
    [ "getAttributeIndexFor", "class_ogre_1_1_vulkan_vao_manager.html#adfdffa2493cff3b6e355ebb9504020f3", null ],
    [ "getAvailableSempaphore", "class_ogre_1_1_vulkan_vao_manager.html#a0e016d616e81de0438c919eb4339126d", null ],
    [ "getAvailableSempaphores", "class_ogre_1_1_vulkan_vao_manager.html#ae09029451f59afca38823c0e58bb31a4", null ],
    [ "getConstBufferAlignment", "class_ogre_1_1_vulkan_vao_manager.html#a4a00e866aebffe5114767ce1fc81bea8", null ],
    [ "getConstBufferMaxSize", "class_ogre_1_1_vulkan_vao_manager.html#a6613f84365a386b9a50fed61a96cfc7a", null ],
    [ "getDefaultStagingBufferLifetime", "class_ogre_1_1_vulkan_vao_manager.html#adb22409286339939dc6d49e44a8f3683", null ],
    [ "getDefaultStagingBufferUnfencedTime", "class_ogre_1_1_vulkan_vao_manager.html#a5388b5890025a724a42f4469363bb267", null ],
    [ "getDescriptorPool", "class_ogre_1_1_vulkan_vao_manager.html#a641004847f314e8a78e0227babd16ab4", null ],
    [ "getDevice", "class_ogre_1_1_vulkan_vao_manager.html#aa7aefe11a585fe9206baa228f7e5ee2b", null ],
    [ "getDrawId", "class_ogre_1_1_vulkan_vao_manager.html#a932e1b238b57f50a1177f98d0541e9c1", null ],
    [ "getDynamicBufferMultiplier", "class_ogre_1_1_vulkan_vao_manager.html#a9b609165fb053afe550711546254e230", null ],
    [ "getFrameCount", "class_ogre_1_1_vulkan_vao_manager.html#ab528ecee92f02772be5dc8329c0e1e1b", null ],
    [ "getMemoryStats", "class_ogre_1_1_vulkan_vao_manager.html#a43a37c0a384ba984e02e7eceac8c3ffb", null ],
    [ "getReadOnlyBufferMaxSize", "class_ogre_1_1_vulkan_vao_manager.html#ae8ea50dfdfc83e13bae02da290647884", null ],
    [ "getStagingBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a2f966c0b38fc30347f429aa85029107a", null ],
    [ "getTexBufferAlignment", "class_ogre_1_1_vulkan_vao_manager.html#a6c4856f0420c296824372ce64825cbfd", null ],
    [ "getTexBufferMaxSize", "class_ogre_1_1_vulkan_vao_manager.html#a2d0feae113e7a1003d76b3640c51d243", null ],
    [ "getTimer", "class_ogre_1_1_vulkan_vao_manager.html#a8e2ce8d89d24f7cd169177f588a6a4d1", null ],
    [ "getUavBufferAlignment", "class_ogre_1_1_vulkan_vao_manager.html#a50170e8b31bd91edd07b36c3fb6678f7", null ],
    [ "getUavBufferMaxSize", "class_ogre_1_1_vulkan_vao_manager.html#ae94298022c4ca57ca88a9440c223af4c", null ],
    [ "initDrawIdVertexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a7de6fa004417e3ea56cfa925cbb12287", null ],
    [ "isFrameFinished", "class_ogre_1_1_vulkan_vao_manager.html#aebcdd34be65546c0936036b2a796b4b1", null ],
    [ "mergeContiguousBlocks", "class_ogre_1_1_vulkan_vao_manager.html#a26844eefd56d60e40f1b13c8c94b2c9f", null ],
    [ "notifySemaphoreUnused", "class_ogre_1_1_vulkan_vao_manager.html#a3b461bb31c7f8e47a94a4725e1d49db1", null ],
    [ "notifyWaitSemaphoresSubmitted", "class_ogre_1_1_vulkan_vao_manager.html#a6ff2db20acf8a0942f25b2304e9056b8", null ],
    [ "notifyWaitSemaphoreSubmitted", "class_ogre_1_1_vulkan_vao_manager.html#aef811ea3cd677a89baea4b86577169ef", null ],
    [ "operator delete", "class_ogre_1_1_vulkan_vao_manager.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_vulkan_vao_manager.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_vulkan_vao_manager.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_vulkan_vao_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_vulkan_vao_manager.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_vulkan_vao_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
    [ "operator new", "class_ogre_1_1_vulkan_vao_manager.html#ab422c67a2c8844f410fe822a357cba3b", null ],
    [ "operator new", "class_ogre_1_1_vulkan_vao_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
    [ "operator new[]", "class_ogre_1_1_vulkan_vao_manager.html#adce32528577d71b228692df906ecd17c", null ],
    [ "operator new[]", "class_ogre_1_1_vulkan_vao_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
    [ "readOnlyIsTexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a62bef9b46aa4eb7100cab724b4b0811a", null ],
    [ "setDefaultStagingBufferlifetime", "class_ogre_1_1_vulkan_vao_manager.html#a445b8e5486e061745af43d1831f60eb6", null ],
    [ "supportsBaseInstance", "class_ogre_1_1_vulkan_vao_manager.html#a7d9d6f2ebaa70d64fc171dd886ae218d", null ],
    [ "supportsCoherentMapping", "class_ogre_1_1_vulkan_vao_manager.html#ac3d2bd7b6a0ea66fadd734eef767562d", null ],
    [ "supportsIndirectBuffers", "class_ogre_1_1_vulkan_vao_manager.html#afce1736c1c28af8657aaf863d366240f", null ],
    [ "supportsNonCoherentMapping", "class_ogre_1_1_vulkan_vao_manager.html#a45b91250168f0f4dcf4e21d5babe7553", null ],
    [ "supportsPersistentMapping", "class_ogre_1_1_vulkan_vao_manager.html#a1945aa252817231abb52b12d4d5399a3", null ],
    [ "waitFor", "class_ogre_1_1_vulkan_vao_manager.html#ab330cf97bef57f8fb7cb8a5488ff13c1", null ],
    [ "waitForSpecificFrameToFinish", "class_ogre_1_1_vulkan_vao_manager.html#ab86e599eefeb66c1c127ac781aa103e8", null ],
    [ "waitForTailFrameToFinish", "class_ogre_1_1_vulkan_vao_manager.html#a80e11dc6fd7754c0dcb8a13fd4d74536", null ],
    [ "VulkanStagingBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a54ef1d4112c8678c370f99209117ce35", null ]
];

==> ogre-next-2.3.1-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/class_ogre_1_1_vulkan_vao_manager.js <==
var class_ogre_1_1_vulkan_vao_manager =
[
    [ "Block", "struct_ogre_1_1_vulkan_vao_manager_1_1_block.html", "struct_ogre_1_1_vulkan_vao_manager_1_1_block" ],
    [ "DirtyBlock", "struct_ogre_1_1_vulkan_vao_manager_1_1_dirty_block.html", "struct_ogre_1_1_vulkan_vao_manager_1_1_dirty_block" ],
    [ "StrideChanger", "struct_ogre_1_1_vulkan_vao_manager_1_1_stride_changer.html", "struct_ogre_1_1_vulkan_vao_manager_1_1_stride_changer" ],
    [ "BlockVec", "class_ogre_1_1_vulkan_vao_manager.html#a0283b00d7e9d9e2213fb148c0373b3b7", null ],
    [ "DirtyBlockArray", "class_ogre_1_1_vulkan_vao_manager.html#a856e4c895201840c4a0a956e6831440e", null ],
    [ "MemoryStatsEntryVec", "class_ogre_1_1_vulkan_vao_manager.html#a8a984ae987b00e95b35198131a4e9a6b", null ],
    [ "StrideChangerVec", "class_ogre_1_1_vulkan_vao_manager.html#af11ca95197171f47071cbdfc64244a4f", null ],
    [ "VboFlag", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6", [
      [ "CPU_INACCESSIBLE", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6adc08b2860b6cf9300228b283c5e651bd", null ],
      [ "CPU_WRITE_PERSISTENT", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6aec008c6e31eaa44bfa5e74b7decb389f", null ],
      [ "CPU_WRITE_PERSISTENT_COHERENT", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6aebeeeb1acff523546cb20cdbded0c5a1", null ],
      [ "CPU_READ_WRITE", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6a4c69f747f4f94bb8b821acc0eacf676a", null ],
      [ "TEXTURES_OPTIMAL", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6ad1e8da73c7fc5e3ce7de33801b73f247", null ],
      [ "MAX_VBO_FLAG", "class_ogre_1_1_vulkan_vao_manager.html#ab58aa47c8a54e57fecd9d7e93b6651a6a1faa3e29dbe49f9f22a09f8d01e18bd0", null ]
    ] ],
    [ "VulkanVaoManager", "class_ogre_1_1_vulkan_vao_manager.html#af585c27cb1ae67c757a1b32df69fb9fe", null ],
    [ "~VulkanVaoManager", "class_ogre_1_1_vulkan_vao_manager.html#a7a7ced25ae7b1eae789a2f415c39aade", null ],
    [ "_beginFrame", "class_ogre_1_1_vulkan_vao_manager.html#ad255ed9aad893f120f6a29e172052ccd", null ],
    [ "_getDynamicBufferCurrentFrameNoWait", "class_ogre_1_1_vulkan_vao_manager.html#a4c2c223f495c035085ffa2b7323bce82", null ],
    [ "_notifyDeviceStalled", "class_ogre_1_1_vulkan_vao_manager.html#a802df1807930b35819e86bb79a733026", null ],
    [ "_notifyNewCommandBuffer", "class_ogre_1_1_vulkan_vao_manager.html#ac786e9cda28b0dc567b9af12e6ddb8a1", null ],
    [ "_notifyStagingBufferEnteredZeroRef", "class_ogre_1_1_vulkan_vao_manager.html#a374058250675bac30bfb5b03c26b5eb7", null ],
    [ "_notifyStagingBufferLeftZeroRef", "class_ogre_1_1_vulkan_vao_manager.html#ace2545e4ce03ff536e3d505e4669cc91", null ],
    [ "_schedulePoolAdvanceFrame", "class_ogre_1_1_vulkan_vao_manager.html#a6c95b6cd736eb88e5dc4f4a0e9a52cae", null ],
    [ "_update", "class_ogre_1_1_vulkan_vao_manager.html#afafd75ba72857e13a55e540a2d0ed414", null ],
    [ "addDelayedFunc", "class_ogre_1_1_vulkan_vao_manager.html#a9c1168472c2c1b564613933fb1c1b6b5", null ],
    [ "allocateRawBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a2870e34d1f38436b26304d046d824aa9", null ],
    [ "allocateTexture", "class_ogre_1_1_vulkan_vao_manager.html#afbc41371222b8bad4d0df08b1edeba2a", null ],
    [ "bindDrawIdVertexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a5ee3a6b573c776419fab5b4da3a0b2fc", null ],
    [ "calculateVertexSize", "class_ogre_1_1_vulkan_vao_manager.html#a222d4e40df5eb53ab0b050e37aca7b89", null ],
    [ "cleanupEmptyPools", "class_ogre_1_1_vulkan_vao_manager.html#aaffa3ad1e24be33801e33b21e028f88d", null ],
    [ "createAsyncTicket", "class_ogre_1_1_vulkan_vao_manager.html#a07071887711dbb653fe790224beb7d3b", null ],
    [ "createConstBuffer", "class_ogre_1_1_vulkan_vao_manager.html#ad918478b8b2fe87bd0cf5a0d800f9ca8", null ],
    [ "createIndexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#aaee81b43cbfe73850b5f48e0b3b04b2d", null ],
    [ "createIndirectBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a62af7df3a3d8cbe692a621741aa12e5c", null ],
    [ "createReadOnlyBuffer", "class_ogre_1_1_vulkan_vao_manager.html#af7c18af1342b5ae1a15d55838b667935", null ],
    [ "createStagingBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a27f67d725f1e4600d946307a831949c8", null ],
    [ "createStagingTexture", "class_ogre_1_1_vulkan_vao_manager.html#a9e35cf192da6357d94b33a75ad94cba6", null ],
    [ "createTexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a9746fd2364a65422ca7beafef42ad82b", null ],
    [ "createUavBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a0937a414f9da637fb8878e10db724bba", null ],
    [ "createVertexArrayObject", "class_ogre_1_1_vulkan_vao_manager.html#a21be4e3d6b7ad0490c59eb9db1cdcdf7", null ],
    [ "createVertexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#aefabb42c2a1a8f2d71af28ffaa91ba91", null ],
    [ "deallocateRawBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a0d085bf800ae5b743106d7494b69f4aa", null ],
    [ "deallocateTexture", "class_ogre_1_1_vulkan_vao_manager.html#a55fb0b0643f47ed4de330528d614ce07", null ],
    [ "deleteStagingBuffers", "class_ogre_1_1_vulkan_vao_manager.html#a204c8055903cea82fe38e6a9fbc62f6d", null ],
    [ "destroyConstBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a51f5147151805c3d294ae200683d76bb", null ],
    [ "destroyIndexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a04c53b84b4c6ba27fdcbf57a08d4b044", null ],
    [ "destroyIndirectBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a4e7e88128e2496523ab0ca8e35634879", null ],
    [ "destroyReadOnlyBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a703bff2ff022184c4f40da6ecb9a19ee", null ],
    [ "destroyStagingTexture", "class_ogre_1_1_vulkan_vao_manager.html#a39ec5e085c6183db97d875c57ca92f0b", null ],
    [ "destroyTexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a6241229a8f3c895dcd49e7d0e8dfe545", null ],
    [ "destroyUavBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a0f235ad527a20a7c20b9daae8dc18ff7", null ],
    [ "destroyVertexArrayObject", "class_ogre_1_1_vulkan_vao_manager.html#a4d56b87f51c489bdc2df07d1ce040512", null ],
    [ "destroyVertexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a1dce3c8cb8c7d08ff77e6c4776fed1f4", null ],
    [ "getAttributeIndexFor", "class_ogre_1_1_vulkan_vao_manager.html#adfdffa2493cff3b6e355ebb9504020f3", null ],
    [ "getAvailableSempaphore", "class_ogre_1_1_vulkan_vao_manager.html#a0e016d616e81de0438c919eb4339126d", null ],
    [ "getAvailableSempaphores", "class_ogre_1_1_vulkan_vao_manager.html#ae09029451f59afca38823c0e58bb31a4", null ],
    [ "getConstBufferAlignment", "class_ogre_1_1_vulkan_vao_manager.html#a4a00e866aebffe5114767ce1fc81bea8", null ],
    [ "getConstBufferMaxSize", "class_ogre_1_1_vulkan_vao_manager.html#a6613f84365a386b9a50fed61a96cfc7a", null ],
    [ "getDefaultStagingBufferLifetime", "class_ogre_1_1_vulkan_vao_manager.html#adb22409286339939dc6d49e44a8f3683", null ],
    [ "getDefaultStagingBufferUnfencedTime", "class_ogre_1_1_vulkan_vao_manager.html#a5388b5890025a724a42f4469363bb267", null ],
    [ "getDescriptorPool", "class_ogre_1_1_vulkan_vao_manager.html#a641004847f314e8a78e0227babd16ab4", null ],
    [ "getDevice", "class_ogre_1_1_vulkan_vao_manager.html#aa7aefe11a585fe9206baa228f7e5ee2b", null ],
    [ "getDrawId", "class_ogre_1_1_vulkan_vao_manager.html#a932e1b238b57f50a1177f98d0541e9c1", null ],
    [ "getDynamicBufferMultiplier", "class_ogre_1_1_vulkan_vao_manager.html#a9b609165fb053afe550711546254e230", null ],
    [ "getFrameCount", "class_ogre_1_1_vulkan_vao_manager.html#ab528ecee92f02772be5dc8329c0e1e1b", null ],
    [ "getMemoryStats", "class_ogre_1_1_vulkan_vao_manager.html#a43a37c0a384ba984e02e7eceac8c3ffb", null ],
    [ "getReadOnlyBufferMaxSize", "class_ogre_1_1_vulkan_vao_manager.html#ae8ea50dfdfc83e13bae02da290647884", null ],
    [ "getStagingBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a2f966c0b38fc30347f429aa85029107a", null ],
    [ "getTexBufferAlignment", "class_ogre_1_1_vulkan_vao_manager.html#a6c4856f0420c296824372ce64825cbfd", null ],
    [ "getTexBufferMaxSize", "class_ogre_1_1_vulkan_vao_manager.html#a2d0feae113e7a1003d76b3640c51d243", null ],
    [ "getTimer", "class_ogre_1_1_vulkan_vao_manager.html#a8e2ce8d89d24f7cd169177f588a6a4d1", null ],
    [ "getUavBufferAlignment", "class_ogre_1_1_vulkan_vao_manager.html#a50170e8b31bd91edd07b36c3fb6678f7", null ],
    [ "getUavBufferMaxSize", "class_ogre_1_1_vulkan_vao_manager.html#ae94298022c4ca57ca88a9440c223af4c", null ],
    [ "initDrawIdVertexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a7de6fa004417e3ea56cfa925cbb12287", null ],
    [ "isFrameFinished", "class_ogre_1_1_vulkan_vao_manager.html#aebcdd34be65546c0936036b2a796b4b1", null ],
    [ "mergeContiguousBlocks", "class_ogre_1_1_vulkan_vao_manager.html#a26844eefd56d60e40f1b13c8c94b2c9f", null ],
    [ "notifySemaphoreUnused", "class_ogre_1_1_vulkan_vao_manager.html#a3b461bb31c7f8e47a94a4725e1d49db1", null ],
    [ "notifyWaitSemaphoresSubmitted", "class_ogre_1_1_vulkan_vao_manager.html#a6ff2db20acf8a0942f25b2304e9056b8", null ],
    [ "notifyWaitSemaphoreSubmitted", "class_ogre_1_1_vulkan_vao_manager.html#aef811ea3cd677a89baea4b86577169ef", null ],
    [ "operator delete", "class_ogre_1_1_vulkan_vao_manager.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_vulkan_vao_manager.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_vulkan_vao_manager.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_vulkan_vao_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_vulkan_vao_manager.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_vulkan_vao_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
    [ "operator new", "class_ogre_1_1_vulkan_vao_manager.html#ab422c67a2c8844f410fe822a357cba3b", null ],
    [ "operator new", "class_ogre_1_1_vulkan_vao_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
    [ "operator new[]", "class_ogre_1_1_vulkan_vao_manager.html#adce32528577d71b228692df906ecd17c", null ],
    [ "operator new[]", "class_ogre_1_1_vulkan_vao_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
    [ "readOnlyIsTexBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a62bef9b46aa4eb7100cab724b4b0811a", null ],
    [ "setDefaultStagingBufferlifetime", "class_ogre_1_1_vulkan_vao_manager.html#a445b8e5486e061745af43d1831f60eb6", null ],
    [ "supportsBaseInstance", "class_ogre_1_1_vulkan_vao_manager.html#a7d9d6f2ebaa70d64fc171dd886ae218d", null ],
    [ "supportsCoherentMapping", "class_ogre_1_1_vulkan_vao_manager.html#ac3d2bd7b6a0ea66fadd734eef767562d", null ],
    [ "supportsIndirectBuffers", "class_ogre_1_1_vulkan_vao_manager.html#afce1736c1c28af8657aaf863d366240f", null ],
    [ "supportsNonCoherentMapping", "class_ogre_1_1_vulkan_vao_manager.html#a45b91250168f0f4dcf4e21d5babe7553", null ],
    [ "supportsPersistentMapping", "class_ogre_1_1_vulkan_vao_manager.html#a1945aa252817231abb52b12d4d5399a3", null ],
    [ "waitFor", "class_ogre_1_1_vulkan_vao_manager.html#ab330cf97bef57f8fb7cb8a5488ff13c1", null ],
    [ "waitForSpecificFrameToFinish", "class_ogre_1_1_vulkan_vao_manager.html#ab86e599eefeb66c1c127ac781aa103e8", null ],
    [ "waitForTailFrameToFinish", "class_ogre_1_1_vulkan_vao_manager.html#a80e11dc6fd7754c0dcb8a13fd4d74536", null ],
    [ "VulkanStagingBuffer", "class_ogre_1_1_vulkan_vao_manager.html#a54ef1d4112c8678c370f99209117ce35", null ]
];
